#!/bin/sh
echo 'name: lens
version: 3.8.7.3
id: lens-3.8.7.3-2ff2805f3542cad08198ccc41189c22d

license: BSD3
copyright: Copyright (C) 2012-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/lens/
package-url:
synopsis: Lenses, Folds and Traversals
description: This package comes \"Batteries Included\" with many useful lenses for the types
             commonly used from the Haskell Platform, and with tools for automatically
             generating lenses and isomorphisms for user-supplied data types.
             .
             The combinators in @Control.Lens@ provide a highly generic toolbox for composing
             families of getters, folds, isomorphisms, traversals, setters and lenses and their
             indexed variants.
             .
             An overview, with a large number of examples can be found in the @README@: <https://github.com/ekmett/lens#lens-lenses-folds-and-traversals>
             .
             A video on how to use lenses and how they are constructed is available from youtube: <http://youtu.be/cefnmjtAolY?hd=1>
             .
             Slides can be obtained here: <http://comonad.com/haskell/Lenses-Folds-and-Traversals-NYC.pdf>
             .
             More information on the care and feeding of lenses, including a brief tutorial and motivation
             for their types can be found on the lens wiki: <https://github.com/ekmett/lens/wiki>
             .
             A small game of @pong@ and other more complex examples that manage their state using lenses can be found in the example folder: <https://github.com/ekmett/lens/blob/master/examples/>
             .
             /Lenses, Folds and Traversals/
             .
             The core of the hierarchy of lens-like constructions looks like:
             .
             <<http://i.imgur.com/RFi75.png>>
             .
             You can compose any two elements of the hierarchy above using @(.)@ from the @Prelude@, and you can
             use any element of the hierarchy as any type it linked to above it.
             .
             The result is their lowest upper bound in the hierarchy (or an error if that bound doesn'\''t exist).
             .
             For instance:
             .
             * You can use any '\''Traversal'\'' as a '\''Fold'\'' or as a '\''Setter'\''.
             .
             * The composition of a '\''Traversal'\'' and a '\''Getter'\'' yields a '\''Fold'\''.
             .
             /Minimizing Dependencies/
             .
             If you want to provide lenses and traversals for your own types in your own libraries, then you
             can do so without incurring a dependency on this (or any other) lens package at all.
             .
             /e.g./ for a data type:
             .
             > data Foo a = Foo Int Int a
             .
             You can define lenses such as
             .
             > -- bar :: Lens'\'' (Foo a) Int
             > bar :: Functor f => (Int -> f Int) -> Foo a -> f (Foo a)
             > bar f (Foo a b c) = fmap (\a'\'' -> Foo a'\'' b c) (f a)
             .
             > -- baz :: Lens (Foo a) (Foo b) a b
             > quux :: Functor f => (a -> f b) -> Foo a -> f (Foo b)
             > quux f (Foo a b c) = fmap (Foo a b) (f c)
             .
             without the need to use any type that isn'\''t already defined in the @Prelude@.
             .
             And you can define a traversal of multiple fields with '\''Control.Applicative.Applicative'\'':
             .
             > -- traverseBarAndBaz :: Traversal'\'' (Foo a) Int
             > traverseBarAndBaz :: Applicative f => (Int -> f Int) -> Foo a -> f (Foo a)
             > traverseBarAndBaz f (Foo a b c) = Foo <$> f a <*> f b <*> pure c
             .
             What is provided in this library is a number of stock lenses and traversals for
             common haskell types, a wide array of combinators for working them, and more
             exotic functionality, (/e.g./ getters, setters, indexed folds, isomorphisms).
category: Data, Lenses
author: Edward A. Kmett
exposed: True
exposed-modules: Control.Exception.Lens Control.Lens
                 Control.Lens.Action Control.Lens.At Control.Lens.Combinators
                 Control.Lens.Cons Control.Lens.Each Control.Lens.Equality
                 Control.Lens.Fold Control.Lens.Getter Control.Lens.Indexed
                 Control.Lens.Internal Control.Lens.Internal.Action
                 Control.Lens.Internal.Bazaar Control.Lens.Internal.ByteString
                 Control.Lens.Internal.Context Control.Lens.Internal.Deque
                 Control.Lens.Internal.Exception Control.Lens.Internal.Fold
                 Control.Lens.Internal.Getter Control.Lens.Internal.Indexed
                 Control.Lens.Internal.Instances Control.Lens.Internal.Iso
                 Control.Lens.Internal.Level Control.Lens.Internal.Magma
                 Control.Lens.Internal.Prism Control.Lens.Internal.Review
                 Control.Lens.Internal.Setter Control.Lens.Internal.Zipper
                 Control.Lens.Internal.Zoom Control.Lens.Iso Control.Lens.Lens
                 Control.Lens.Level Control.Lens.Loupe Control.Lens.Operators
                 Control.Lens.Plated Control.Lens.Prism Control.Lens.Reified
                 Control.Lens.Review Control.Lens.Setter Control.Lens.Simple
                 Control.Lens.TH Control.Lens.Traversal Control.Lens.Tuple
                 Control.Lens.Type Control.Lens.Wrapped Control.Lens.Zipper
                 Control.Lens.Zoom Control.Monad.Error.Lens
                 Control.Parallel.Strategies.Lens Control.Seq.Lens Data.Array.Lens
                 Data.Bits.Lens Data.ByteString.Lens Data.ByteString.Strict.Lens
                 Data.ByteString.Lazy.Lens Data.Complex.Lens Data.Data.Lens
                 Data.Dynamic.Lens Data.HashSet.Lens Data.IntSet.Lens Data.List.Lens
                 Data.List.Split.Lens Data.Sequence.Lens Data.Set.Lens
                 Data.Text.Lens Data.Text.Strict.Lens Data.Text.Lazy.Lens
                 Data.Tree.Lens Data.Typeable.Lens Data.Vector.Lens
                 Data.Vector.Generic.Lens Generics.Deriving.Lens GHC.Generics.Lens
                 System.Exit.Lens System.FilePath.Lens System.IO.Error.Lens
                 Language.Haskell.TH.Lens Numeric.Lens
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/lens-3.8.7.3
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/lens-3.8.7.3
              /usr/local/lib
hs-libraries: HSlens-3.8.7.3
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: MonadCatchIO-transformers-0.3.0.0-3d9f2598a492284fcb08e73b1981b4a4
         array-0.4.0.0-4f6c2a594155b0b953c1cf0f54040f61
         base-4.5.1.0-12fddc14a7babb909dd3843e453b5660
         bifunctors-3.2.0.1-e425541f009d8e13bfb2163261008611
         bytestring-0.9.2.1-e22c77999d0db34f3ca8de7082a3ffd5
         comonad-3.0.2-b0ceee3eca078a4979462cf2e86c7b95
         comonad-transformers-3.0.1-7f9e068cc7341147f7b9e44b5f18aa3c
         comonads-fd-3.0.1-efb20ed6f327222ca93741b3b80d193c
         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
         contravariant-0.4-88891eca02b1bda6d03085d1b1009c6d
         distributive-0.3.1-62d87d0ef3d08719b0d6a8f59a23419d
         filepath-1.3.0.0-954c43b4f109cbd4121f1231c14d5cff
         generic-deriving-1.4.0-4a40e028aff7443915b091344cc78d02
         ghc-prim-0.2.0.0-23f345e1ec26a64d5ebc768bd0b2a5d9
         hashable-1.2.0.5-616c9310810e53cea406a20719f1a423
         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
         parallel-3.2.0.3-0c734151f27a50a329a35e705f0ba330
         profunctor-extras-3.3-0fefced3784e6aefaac36421b996c362
         profunctors-3.3-74073f145fb666c6bb2abab6944673af
         reflection-1.1.7-4cf7cbdc7e15639bf48bf586753d7811
         semigroupoids-3.0.2-1ab2a6bd02a051ca9ce83fb386006a96
         semigroups-0.9-7e502949bc7c9e3e2d6f68db86ac326f
         split-0.2.1.1-d0476313c57b84b6637b0d5a6dc092dc
         tagged-0.4.4-55c603ce43bd5a4d0399cb94469b9536
         template-haskell-2.7.0.0-60724b98c233a73b2347be7414bd58d0
         text-0.11.2.3-366962ac4488fc093d5aed19e281b055
         transformers-0.3.0.0-2889ebed7e61112cda7ded5e4c153bcf
         unordered-containers-0.2.3.0-2418b77932f7b961dfa1314968c1e9ff
         vector-0.10.0.1-fdf8e0c3f3c1cae1113ab97c34aa5c14
         void-0.5.11-5e2e8ce64c41580ed2706249cdec2c4f
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/lens-3.8.7.3/html/lens.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/lens-3.8.7.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
